==> spring-cloud-sleuth-core-2.1.2.RELEASE-sources.jar: org/springframework/cloud/sleuth/instrument/messaging/TraceMessageHeaders.java <==
/*
 * Copyright 2013-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.sleuth.instrument.messaging;

/**
 * Contains trace related messaging headers. The deprecated headers contained `-` which
 * for example in the JMS specs is invalid. That's why the public constants in this class
 * represent the valid names for the tracing headers.
 *
 * @author Marcin Grzejszczak
 * @since 1.0.4
 */
public final class TraceMessageHeaders {

	/**
	 * Span ID message header name.
	 */
	public static final String SPAN_ID_NAME = "spanId";

	/**
	 * Span sampled message header name.
	 */
	public static final String SAMPLED_NAME = "spanSampled";

	/**
	 * Parent span ID message header name.
	 */
	public static final String PARENT_ID_NAME = "spanParentSpanId";

	/**
	 * Trace ID message header name.
	 */
	public static final String TRACE_ID_NAME = "spanTraceId";

	/**
	 * Span name message header name.
	 */
	public static final String SPAN_NAME_NAME = "spanName";

	/**
	 * Span flags message header name.
	 */
	public static final String SPAN_FLAGS_NAME = "spanFlags";

	private TraceMessageHeaders() {
	}

}

==> spring-cloud-sleuth-core-2.2.4.RELEASE-sources.jar: org/springframework/cloud/sleuth/instrument/messaging/TraceMessageHeaders.java <==
/*
 * Copyright 2013-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.sleuth.instrument.messaging;

import brave.propagation.B3Propagation;

/**
 * Contains trace related messaging headers. The deprecated headers contained `-` which
 * for example in the JMS specs is invalid. That's why the public constants in this class
 * represent the valid names for the tracing headers.
 *
 * @author Marcin Grzejszczak
 * @since 1.0.4
 * @deprecated These names are obviated by {@link B3Propagation.Format#SINGLE}.
 */
@Deprecated
public final class TraceMessageHeaders {

	/**
	 * Span ID message header name.
	 */
	public static final String SPAN_ID_NAME = "spanId";

	/**
	 * Span sampled message header name.
	 */
	public static final String SAMPLED_NAME = "spanSampled";

	/**
	 * Parent span ID message header name.
	 */
	public static final String PARENT_ID_NAME = "spanParentSpanId";

	/**
	 * Trace ID message header name.
	 */
	public static final String TRACE_ID_NAME = "spanTraceId";

	/**
	 * Span name message header name.
	 */
	public static final String SPAN_NAME_NAME = "spanName";

	/**
	 * Span flags message header name.
	 */
	public static final String SPAN_FLAGS_NAME = "spanFlags";

	private TraceMessageHeaders() {
	}

}
